%% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %%
%% This is a class file for articles published in  %%
%%                                                 %%
%%   Zeitschrift für Mathematische Logik           %%
%%   und Grundlagen der Mathematik                 %%
%%                                                 %%
%% Last Modification: 26.05.2025                   %%
%% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %%


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{zml-article}
[2025/05/26 ZML Article Class]

\newcommand{\zml@error}[1]{\ClassError{zml-article}{#1}}
\newcommand{\zml@warning}[1]{\ClassWarning{zml-article}{#1}}
\def\zml@debug{0}
\def\zml@biblatex{0}
\newcommand{\zmldebug}{\def\zml@debug{1}\zml@warning{In debug mode.}}
\newcommand{\zmlbiblatex}[1]{\def\zml@biblatex{1}\def\zml@bibsource{#1}}

%% Inherit basic layout from 'article' class
\LoadClass[10pt]{article}

%% Page size, margins, etc.
\RequirePackage[
twoside=true,
paperwidth=210mm,
paperheight=276mm,
top=30mm,
bottom=24mm,
left=21mm,
right=21mm
]{geometry}


%% Math packages
\RequirePackage[fleqn]{amsmath}
\RequirePackage{amssymb}


%% Make distance between lines larger so that most inline mathematical
%% notation does not disturb the line distance.
\RequirePackage{setspace}
\RequirePackage{etoolbox}
\let\@xfloat=\latex@xfloat
\newcommand{\zmlreduceintersection}{\vspace*{-\topsep}}

%% Indentation behaviour, spacing for itemize and enumerate
\RequirePackage{enumitem}
\let\@afterindentfalse\@afterindenttrue
\@afterindenttrue
\newcommand{\zml@customlengths}{%
	\baselineskip 13.5\p@ \@minus.5\p@
	\abovedisplayskip 8\p@ \@plus4\p@ \@minus2\p@
	\belowdisplayskip \abovedisplayskip
	\abovedisplayshortskip \abovedisplayskip
	\belowdisplayshortskip \abovedisplayskip
	\parsep 0\p@ \@plus1\p@
	\topsep 4\p@ \@plus2\p@ \@minus1\p@
	\itemsep 0\p@ \@plus1\p@
}
\setlength{\parindent}{5mm}
\setlength{\mathindent}{2\parindent}
\appto\normalsize\zml@customlengths

\AtBeginDocument{%
	\normalsize
	\flushbottom%
}
\selectfont
\setlist{
	listparindent=\parindent,
	leftmargin=2\parindent,
	labelsep=.4\parindent,
	itemsep=0pt,
	parsep=\parskip,
	topsep=.5\topsep
}
\setlist[enumerate,1]{label=(\arabic*)}
\setlist[enumerate,2]{label=(\alph*),parsep=0pt,topsep=0pt,leftmargin=\parindent}
\setlist[enumerate,3]{label=(\roman*),parsep=0pt,topsep=0pt,leftmargin=\parindent}
\setlist[enumerate,4]{label=(\Roman*),parsep=0pt,topsep=0pt,leftmargin=\parindent}
\setlist[itemize,2]{parsep=0pt,topsep=0pt,leftmargin=\parindent}
\setlist[itemize,3]{parsep=0pt,topsep=0pt,leftmargin=\parindent}
\setlist[itemize,4]{parsep=0pt,topsep=0pt,leftmargin=\parindent}

\RequirePackage{microtype}
\RequirePackage[T1]{fontenc}
\RequirePackage{lmodern}

%% Titlepage packages
\RequirePackage{lastpage}
\RequirePackage{xifthen}
\RequirePackage{fancyhdr}
\RequirePackage{graphicx}

%% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %%
%% The following gathers the authors and their affiliations.   %%
%% It is loosely based on authblk.sty                          %%
%% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %%

\newcounter{authorcount}
\setcounter{authorcount}{0}
\newcounter{affilcount}
\setcounter{affilcount}{0}
\newcounter{authnotecount}
\setcounter{authnotecount}{0}

\newcommand\zml@superscript[1]{\textsuperscript{\normalfont#1}}
\newcommand\zml@superscriptnospace[1]{\hspace*{-1em}\parbox{1em}{\raggedleft\textsuperscript{\normalfont#1}}}
\providecommand\textsuperscript[1]{$^{#1}$}

\renewcommand{\author}[2][]{%
	\stepcounter{authorcount}%
	\expandafter\gdef\csname zmltempauthor\arabic{authorcount}\endcsname{#2}%
	\expandafter\gdef\csname zmltempauthorsup\arabic{authorcount}\endcsname{#1}%
	\def\zml@authparam{#1}%
	\ifx\zml@authparam\empty\zml@warning{No affiliation provided for author #2!}\fi
}
\newcommand{\affil}[2][]{%
	\stepcounter{affilcount}%
	\expandafter\gdef\csname zmltempaffil\arabic{affilcount}\endcsname{#2}%
	\expandafter\gdef\csname zmltempaffilsup\arabic{affilcount}\endcsname{#1}%
}

\newcommand{\authors}{%
	\ifnum\value{authorcount}=0
	{Anonymous}%
	\zml@warning{No authors provided, please provide authors in the preamble with the command \protect\author[<superscript>]{<author name>}. The superscript refers the authors to their affiliations.}
	\else
	\csname zmltempauthor1\endcsname\zml@superscript{(\csname zmltempauthorsup1\endcsname)}%
	\ifnum\value{authorcount}=1
	\else
	\newcount\@tempcnta
	\@tempcnta=2
	\loop
	\ifnum\@tempcnta>\value{authorcount}
	\else
	\qquad\csname zmltempauthor\the\@tempcnta\endcsname\zml@superscript{(\csname zmltempauthorsup\the\@tempcnta\endcsname)}%
	\advance\@tempcnta by 1
	\repeat
	\fi
	\fi
}
\newcommand{\authorlist}{% Provides the same list as \authors, but now comma separated
	\ifnum\value{authorcount}=0
	{Anonymous}%
	\else
	\zml@superscript{}\csname zmltempauthor1\endcsname%
	\ifnum\value{authorcount}=1
	\else
	\newcount\@tempcnta
	\@tempcnta=2
	\loop
	\ifnum\@tempcnta>\value{authorcount}
	\else
	,\space\csname zmltempauthor\the\@tempcnta\endcsname%
	\advance\@tempcnta by 1
	\repeat
	\fi
	\fi
}
\newcommand{\affillist}{% Provides the list of affiliations
	\ifnum\value{affilcount}=0
	{No affiliations provided}%
	\zml@warning{No affiliations provided, please provide affiliations for the authors in the preamble with the command \protect\affil[<superscript>]{<affiliation name>}. The superscript should correspond to the affiliated author.}
	\else
	\zml@superscript{(\csname zmltempaffilsup1\endcsname)} \protect\parbox[t]{.95\textwidth}{\raggedright\csname zmltempaffil1\endcsname}%
	\ifnum\value{affilcount}=1
	\else
	\newcount\@tempcnta
	\@tempcnta=2
	\loop
	\ifnum\@tempcnta>\value{affilcount}
	\else
	\protect\vspace*{.2em}\\\zml@superscript{(\csname zmltempaffilsup\the\@tempcnta\endcsname)} \protect\parbox[t]{.95\textwidth}{\raggedright\csname zmltempaffil\the\@tempcnta\endcsname}%
	\advance\@tempcnta by 1
	\repeat
	\fi
	\fi
}

%% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %%
%% This concludes the gathering of authors and affiliations.   %%
%% Below \maketitle is defined, creating the first page        %%
%% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %% %%

\def\zml@titleformatA{\normalfont}% Title format for article title
\def\zml@titleformatB{\zml@titleformatA}% Title & author format for margins
\def\zml@titleformatC{\zml@titleformatA}% Format for section headers

\def\zml@title{\@title}%
\def\zml@authorlist{\authorlist}%
\newcommand\corrauthor[2]{\def\zml@corrauthor{#1, }\def\zml@corremail{\href{mailto:#2}{\texttt{#2}}}}
\newcommand\shortauthors[1]{\def\zml@authorlist{#1}}
\newcommand\shorttitle[1]{\def\zml@title{#1}}
\newcommand\zmlvolume[1]{\def\zml@volume{#1}}
\newcommand\zmlpubdate[1]{\def\zml@pubdate{#1}}
\newcommand\zmlissue[1]{\def\zml@issue{#1}}
\newcommand\zmlfirstpage[1]{\def\zml@firstpage{#1}\setcounter{page}{#1}}
\newcommand\zmlreceived[1]{\def\zml@received{#1}}
\newcommand\zmlrevised[1]{\def\zml@revised{#1}}
\newcommand\zmlaccepted[1]{\def\zml@accepted{#1}}
\newcommand\zmldoi[1]{\def\zml@doi{#1}}

\renewcommand\thanks[1]{\def\zml@thanks{#1}}
\newcommand\printthanks{%
	\ifx\zml@thanks\undefined\else%
	\vspace*{\baselineskip}\par%
	\noindent\textit{Acknowledgements.}\hspace*{1em}%
	\zml@thanks%
	\fi%
}

%% Setting up custom pagestyle for first page:

\fancypagestyle{firstpage}
{
	\fancyhf{}
	\fancyfoot[C]{\vspace*{-1.7em}\\\thepage}
	\fancyfoot[L]{\vspace*{.5em}\\\hspace*{-17mm}\footnotesize\ifx\zml@cc\undefined\else\zml@cc\fi}
	\renewcommand{\headrulewidth}{0pt} % removes horizontal header line
}


\newcommand\zmlcc[3][]{
	\def\zml@cczero{#2}
	\def\zml@ccothercopyright{#1}
	\ifx\zml@cczero\empty
	\def\zml@cc{%
		\parbox[c][2.5em]{.11\textwidth}{\href{https://creativecommons.org/publicdomain/zero/1.0/}{\IfFileExists{cc/ZERO.png}{\includegraphics[height=2em]{cc/ZERO.png}}{nofile}}}%
		\parbox[c][2.5em]{.89\textwidth}{This article has been released into the public domain under   \href{https://creativecommons.org/publicdomain/zero/1.0/}{CC0}.\\No copyright is retained by the author\ifnum\value{authorcount}>1s\fi.\vspace*{-.7mm}}
	}
	\else
	\def\zml@cc{%
		\parbox[c][2.5em]{.11\textwidth}{\href{https://creativecommons.org/licenses/#2/#3/}{\IfFileExists{cc/#2.png}{\includegraphics[height=2em]{cc/#2.png}}{nofile}}}%
		\parbox[c][2.5em]{.89\textwidth}{This article is licensed under the \href{https://creativecommons.org/licenses/#2/#3/}{Creative Commons #2 #3 license}. \\Copyright is retained by 
			\ifx\zml@ccothercopyright\empty%
			the author\ifnum\value{authorcount}>1s\fi%
			\else%
			#1
			\fi.\vspace*{-.7mm}}
	}
	\fi
}

\renewcommand{\abstract}[1]{
	\ifx\zml@titleprinted\undefined%
	\def\zml@abstract{#1}%
	\else
	\zml@error{Abstract should be defined before \protect\maketitle.}%
	\fi
}
\renewcommand{\maketitle}{%
	\def\zml@titleprinted{1}%
	\thispagestyle{firstpage}
	\vspace*{-5.5em}
	\noindent\begin{minipage}[b]{.5\textwidth}
		\setstretch{.7}
		\small
		\ifx\zml@volume\undefined%
		\else
		\ifx\zml@volume\empty%
		Early view
		\else
		Volume \zml@volume%
		\ifx\zml@issue\undefined%
		\else%
		,\ Number \zml@issue%
		\fi%
		,\ \zml@pubdate, pp.\ \thepage-\pageref*{LastPage}%
		\fi%
		\vspace*{.4em}\\
		{\footnotesize\itshape
			\makebox[4.5em][l]{Received:} \zml@received%
			\ifx\zml@revised\undefined%
			\else\\
			\makebox[4.5em][l]{Revised:} \zml@revised%
			\fi\\
			\makebox[4.5em][l]{Accepted:} \zml@accepted
		}\vspace*{.4em}\\\ifx\zml@doi\empty%
		{\scshape doi:}\ \textlangle will appear here\textrangle.
		\zml@warning{No DOI has been provided}
		\else%
		{\scshape doi:}\ \protect\href{https://doi.org/\zml@doi}{\zml@doi}
		\fi
		\fi
	\end{minipage}\hfill
	\noindent\begin{minipage}[b]{.4\textwidth}
		\IfFileExists{./zml-logo.png}%
		{\parbox[b][.33\textwidth]{\textwidth}{\includegraphics[width=\textwidth]{zml-logo.png}}}%
		{\parbox[b][.33\textwidth]{\textwidth}{\raggedleft\large[$\mathsf{ZML}$]}}%
	\end{minipage}\vspace*{2em}
	
	\begin{center}
		\parbox{\textwidth}{\centering\huge\zml@titleformatA\@title}
		
		\vspace*{2em}
		
		{\large\authors}\vspace*{1em}
	\end{center}
	{\setstretch{1}\normalsize \affillist}\vspace{1.5em}
	\begin{center}
		\begin{minipage}[t]{.85\textwidth}\setstretch{1.1}%
			\setlength{\parindent}{1.5em}
			\small\noindent%
			{\itshape Abstract.}\quad
			\ifx\zml@abstract\undefined
			Not provided.%
			\zml@warning{No abstract given, please provide an abstract in the preamble with the command \protect\abstract{⟨your abstract⟩}.}
			\else
			\zml@abstract
			\fi
		\end{minipage}\hspace*{1em}
	\end{center}\vspace*{1em}%
	\ifx\zml@corrauthor\undefined%
	\zml@warning{No correspondence email provided, please provide a corresponding author with the command \protect\corrauthor{⟨author name⟩}{⟨email⟩}.}
	\else%
	\let\zml@tempfootnote\thefootnote
	\let\thefootnote\relax
	\footnotetext{\hspace*{-5mm}\ifnumequal{\value{authorcount}}{1}{\emph{Correspondence email:} }{\emph{Corresponding author:} \zml@corrauthor}\zml@corremail}
	\let\thefootnote\zml@tempfootnote
	\fi
}

%% %% %% %% %% %% %% %% %% %% %% %% %% %%
%% End of the definition of \maketitle %%
%% %% %% %% %% %% %% %% %% %% %% %% %% %%

%% Section headers
\RequirePackage{titlesec}

\titleformat{\section}{\setstretch{1}\LARGE\zml@titleformatC}{\thesection}{1em}{\raggedright}
\titleformat{\subsection}{\setstretch{1}\Large\zml@titleformatC}{\thesubsection}{1em}{\raggedright}
\titleformat{\subsubsection}{\setstretch{1}\large\zml@titleformatC}{\thesubsubsection}{1em}{\raggedright}
\titleformat{\paragraph}[runin]
{\normalfont\normalsize\bfseries}{\theparagraph}{1em}{}
\titleformat{\subparagraph}[runin]
{\normalfont\normalsize\bfseries}{\thesubparagraph}{1em}{}

\titlespacing*{\paragraph}
{0pt}{1ex plus 1ex minus .2ex}{1em}
\titlespacing*{\subparagraph} {\parindent}{1ex plus 0ex minus .2ex}{1em}

%% Stylise figure and tables
\RequirePackage{caption}
\def\fnum@figure{{\itshape \figurename\nobreakspace\thefigure.}}
\def\fnum@table{{\itshape \tablename\nobreakspace\thetable.}}
\def\zmltextlesscaption{\caption{}}
\RequirePackage{booktabs}
\RequirePackage{subcaption}

%% Fancyhdr for headers and footers, article title on odd pages, authors on even
\pagestyle{fancy}
\fancyhead[C]{}
\fancyhead[LO]{\parbox[b][0pt]{.95\textwidth}{\raggedright \zml@titleformatB\zml@title}}
\fancyhead[RE]{\parbox[b][0pt]{.95\textwidth}{\raggedleft \zml@titleformatB\zml@authorlist}}
\fancyhead[RO,LE]{\thepage}
\fancyfoot[C]{} % Remove pagenumber from footer
\setlength{\headheight}{14pt}
\addtolength{\footnotesep}{1mm}
\RequirePackage[bottom,multiple]{footmisc} % Footnotes at the bottom
\renewcommand{\hangfootparindent}{14pt}
\renewcommand\@makefntext[1]{\leftskip=0em\hskip0em\makebox[5mm][l]{\@makefnmark}{\setlength{\parindent}{5mm}#1}}



%\renewcommand{\hangfootparindent}{5mm}
%\renewcommand{\footnotemargin}{5mm}

%% Theorem styling
\RequirePackage{amsthm}
\RequirePackage{thmtools}
\newtheoremstyle{plain}
{\topsep} % Space above
{\topsep} % Space below
{\normalfont} % Body font
{} % Indent amount
{\bfseries} % Theorem head font
{.} % Punctuation after theorem head
{1em} % Space after theorem head
{} % Theorem head spec (can be left empty, meaning `normal')


%% Proof styling
\renewenvironment{proof}[1][\proofname]{%\par
	\pushQED{\qed}%
	\normalfont \topsep\p@\@plus0\p@\relax
	\trivlist
	\item[\hskip\labelsep
	\itshape
	#1\@addpunct{.}]\ignorespaces
}{%
	\popQED\endtrivlist\@endpefalse
}
\providecommand{\proofname}{Proof}

%% Renaming symbols
\AtBeginDocument{%
	\NewCommandCopy{\phiold}{\phi}%
	\NewCommandCopy{\rhoold}{\rho}%
	\NewCommandCopy{\epsilonold}{\epsilon}%
	\NewCommandCopy{\emptysetold}{\emptyset}%
	\RenewCommandCopy{\phi}{\varphi}%
	\RenewCommandCopy{\rho}{\varrho}%
	\RenewCommandCopy{\epsilon}{\varepsilon}%
	\RenewCommandCopy{\emptyset}{\varnothing}%
}

%% %% %% %% %% %% %% %% %% %%
%% Line breaking behaviour %%
%% %% %% %% %% %% %% %% %% %%

\adjdemerits=100
\linepenalty=100
\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301
\clubpenalty 10000
\widowpenalty 10000
\displaywidowpenalty 100
\predisplaypenalty   10000
\postdisplaypenalty  0
\doublehyphendemerits 1000000% corresponds to badness 800
\finalhyphendemerits  1000000% corresponds to badness 1000
\vbadness=9999
\tolerance=9999
\interlinepenalty 0
\brokenpenalty 10000
\lefthyphenmin=3
\righthyphenmin=3

%% Hyperref setup
\RequirePackage{hyperref}

\AtEndPreamble{
	\ifnum\zml@debug=0%
	\hypersetup{
		colorlinks=true,
		allcolors=black,
	}
	\else
	\hypersetup{
		colorlinks=true,
		allcolors=blue,
	}
	\fi
}

\endinput
